@@ -2,7 +2,7 @@ import logging
 from typing import List
 
 from bitfield import Bit, BitHandler
-from django.core.exceptions import EmptyResultSet
+from django.core.exceptions import EmptyResultSet, FieldError
 from django.db import connection, transaction
 from django.db.models import Manager, QuerySet, Q, ForeignKey
 from django.forms import model_to_dict
@@ -392,7 +392,7 @@ class CommonQuerySet(QuerySet):
                     queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull=True)
         return queryResult
 
-    def get_range_rows(self, start=None, end=None, function=None, json=None, distinct_field_names=None, *args, **kwargs):
+    def get_range_rows(self, start=None, end=None, function=None, json=None, distinct_field_names=None, user=None, *args, **kwargs):
         queryResult = self._get_range_rows(*args, start=start, end=end, function=function, json=json, distinct_field_names=distinct_field_names)
 
         try:
@@ -420,7 +420,15 @@ class CommonQuerySet(QuerySet):
 
         self.alive_only = request.alive_only
         self.enabledAll = request.enabledAll
-        res = self.get_range_rows(start=request.startRow, end=request.endRow, function=function, distinct_field_names=distinct_field_names, json=request.json, criteria=request.get_criteria())
+        res = self.get_range_rows(
+            start=request.startRow,
+            end=request.endRow,
+            function=function,
+            distinct_field_names=distinct_field_names,
+            json=request.json,
+            criteria=request.get_criteria(),
+            user=request.user
+        )
         return res
 
     def get_range_rows2(self, *args, **kwargs):
